@@ -5,7 +5,7 @@ from unittest.mock import patch
 from cast_from_env import from_env
 
 
-class XMLTests(TestCase):
+class UnitTests(TestCase):
 
     @patch.dict(environ, {'TEST_STR': 'a string', 'TEST_INT': '123', 'TEST_FLOAT': '12.34',
                           'TEST_TRUE': 'true', 'TEST_FALSE': 'no'})
@@ -17,3 +17,4 @@ class XMLTests(TestCase):
         assert type(from_env('TEST_FLOAT', float)) is float, 'Env var is cast to float'
         assert from_env('TEST_TRUE', bool) is True, '"true" cast to bool is True'
         assert from_env('TEST_FALSE', True) is False, '"no" cast to bool is False'
+        assert from_env('TEST_UNSET', True) is True, 'unset var cast to bool returns default'
